@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,22 +30,25 @@
 #include <qglobal.h>
 
 #include <kapp.h>
-#include <kmsgbox.h>
+#include <klocale.h>
+#include <kmessagebox.h>
 
 #include "downloaddlg.h"
 #include "global.h"
 
 
 
-DownloadDlg::DownloadDlg(QWidget *parent, const char *name, bool modal, WFlags f) : QProgressDialog(parent, name, modal, f)
+DownloadDlg::DownloadDlg(QWidget *parent, const char *name) : QProgressDialog(parent, name, false)
 {
-	config = kapp->getConfig();
+	config = kapp->config();
 	
 	modem = new Modem(this, "modem");
 	CHECK_PTR(modem);
 	init();
 
 	setMinimumDuration(0);
+	setAutoReset(false);
+	setAutoClose(false);
 
 	connect(modem, SIGNAL(gotLine(const char *)), SLOT(fetchModemLine(const char *)));
 	connect(modem, SIGNAL(gotXBlock(const uchar *, int)), SLOT(fetchXModemBlock(const uchar *, int)));
@@ -89,16 +92,16 @@ bool DownloadDlg::startDownload()
 	modem->setStop(1);
 
 	if (!modem->open()) {
-		KMsgBox::message(0, i18n("Modem Error"), i18n("Cannot open modem device."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot open modem device."), i18n("Modem Error"));
 		return false;
 	}
 	if (!modem->dsrOn()) {
-		KMsgBox::message(0, i18n("Modem Error"), i18n("Modem is off."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Modem is off."), i18n("Modem Error"));
 		modem->close();
 		return false;
 	}
 	if (!modem->ctsOn()) {
-		KMsgBox::message(0, i18n("Modem Error"), i18n("Modem is busy."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Modem is busy."), i18n("Modem Error"));
 		modem->close();
 		return false;
 	}
@@ -120,8 +123,10 @@ void DownloadDlg::cancel()
 
 	if (status == 3)
 		modem->abortXModem();
-	else
+	else {
 		reset();
+		emit done();
+	}
 }
 
 
@@ -166,7 +171,8 @@ void DownloadDlg::fetchModemLine(const char *line)
 					fitems->size = size;
 					nfiles++;
 				}
-			} else if (!strcmp(line, "OK")) {
+			}
+			else if (!strcmp(line, "OK")) {
 				usleep(250000);
 				count = 0;
 				status++;
@@ -178,8 +184,7 @@ void DownloadDlg::fetchModemLine(const char *line)
 				usleep(250000);
 
 				if (delete_fax) {
-					sprintf(buff, "AT$JDEL=\"%s\"", fitems->name);
-					modem->writeLine(buff);
+					modem->writeLine(QString("AT$JDEL=\"%1\"").arg(fitems->name));
 					status++;
 				} else {
 					setProgress(fitems->size + 1);
@@ -226,9 +231,10 @@ void DownloadDlg::fetchXModemDone(bool success)
 		if (success)
 			emit gotFile(fitems->file);
 		else {
-			emit message(s.sprintf("%s: %s", i18n("Error"), i18n("Download failed.")));
+			emit message(QString("%1: %2").arg(i18n("Error")).arg(i18n("Download failed.")));
 
 			reset();
+			emit done();
 		}
 		setLabelText(i18n("Waiting for confirmation..."));
 	}
@@ -239,11 +245,12 @@ void DownloadDlg::fetchTimeout()
 {
 	QString s;
 	
-	KMsgBox::message(0, i18n("Modem Error"), i18n("Modem response timeout."), KMsgBox::EXCLAMATION);
+	KMessageBox::sorry(this, i18n("Modem response timeout."), i18n("Modem Error"));
 
-	emit message(s.sprintf("%s: %s", i18n("Error"), i18n("Modem response timeout.")));
+	emit message(QString("%1: %2").arg(i18n("Error")).arg(i18n("Modem response timeout.")));
 
 	reset();
+	emit done();
 }
 
 
@@ -279,7 +286,7 @@ void DownloadDlg::reset()
 
 	init();
 
-	emit done();
+	hide();
 }
 
 
@@ -291,23 +298,27 @@ void DownloadDlg::downloadFile()
 		count++;
 		file.setName(expandPath(fitems->file));
 		if (!file.open(IO_WriteOnly)) {
-			KMsgBox::message(0, i18n("File Error"), i18n("Cannot create file."), KMsgBox::EXCLAMATION);
-			emit message(s.sprintf("%s: %s!", i18n("Error"), i18n("Download failed")));
+			KMessageBox::sorry(this, i18n("Cannot create file."), i18n("File Error"));
+			emit message(QString("%1: %2!").arg(i18n("Error")).arg(i18n("Download failed")));
 			reset();
+			emit done();
 
 			return;
 		}
-		modem->writeLine(s.sprintf("AT$JDNL=\"%s\"", fitems->name));
-		setLabelText(s.sprintf(i18n("Receiving file %d of %d..."), count, nfiles));
-		setTotalSteps(fitems->size + 1);
+		modem->writeLine(QString("AT$JDNL=\"%1\"").arg(fitems->name));
+		QProgressDialog::reset();
+		setLabelText(i18n("Receiving file %1 of %2...").arg(count).arg(nfiles));
+		setTotalSteps(fitems->size);
 		setProgress(0);
 		modem->receiveXModem(true);
-	} else {
+	}
+	else {
 		if (nfiles)
-			emit message(s.sprintf(i18n("Received %d file(s)."), nfiles));
+			emit message(i18n("Received %1 file(s).").arg(nfiles));
 		else
 			emit message(i18n("No facsimile in modem."));
 
 		reset();
+		emit done();
 	}
 }
