@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ class DownloadDlg : public QProgressDialog
 {
 	Q_OBJECT
 public:
-	DownloadDlg(QWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags f = 0);
+	DownloadDlg(QWidget *parent = 0, const char *name = 0);
 	~DownloadDlg();
 
 	bool startDownload();
