@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include <qdir.h>
 
 #include <kapp.h>
+#include <klocale.h>
 #include <kiconloader.h>
 #include <ksimpleconfig.h>
 
@@ -43,7 +44,7 @@
 
 
 
-FaxViewItem::FaxViewItem(QListView *parent = 0, const char *name = 0) : QListViewItem(parent, name)
+FaxViewItem::FaxViewItem(QListView *parent, const char *name) : QListViewItem(parent, name)
 {
 	m_new = false;
 	m_sender[0] = 0;
@@ -58,17 +59,17 @@ FaxViewItem::~FaxViewItem()
 }
 
 
-void FaxViewItem::setName(const QString& name)
+void FaxViewItem::setName(const QString& name_)
 {
-	setText(0, name);
-	setText(2, mloDateStr(name));
+	setText(0, name_);
+	setText(2, mloDateStr(name_));
 }
 
 
 void FaxViewItem::setNew(bool isnew)
 {
 	m_new = isnew;
-	setPixmap(1, m_new ? Icon("yes.xpm") : Icon("no.xpm"));
+	setPixmap(1, m_new ? UserIcon("yes") : UserIcon("no"));
 }
 
 
@@ -87,25 +88,21 @@ void FaxViewItem::setPages(int pages_)
 	QString s;
 
 	m_pages = pages_;
-	s.sprintf("%3d", pages_);
-	setText(4, s);
+	setText(4, s.setNum(pages_));
 }
 
 
 void FaxViewItem::setSize(uint size_)
 {
-	QString s;
-
 	m_size = size_;
-	s.sprintf("%7u", size_);
-	setText(5, s);
+	setText(5, KGlobal::locale()->formatNumber((double)size_, 0));
 }
 
 
 void FaxViewItem::setFile(bool hasfile)
 {
 	m_file = hasfile;
-	setPixmap(6, m_file ? Icon("yes.xpm") : Icon("no.xpm"));
+	setPixmap(6, m_file ? UserIcon("yes") : UserIcon("no"));
 }
 
 
@@ -126,9 +123,9 @@ void FaxViewItem::setParams(const QString& name_, bool isnew_, const char *sende
 }
 
 
-FaxView::FaxView(QWidget *parent, const char *name) : QListView(parent, name)
+FaxView::FaxView(QWidget *parent, const char *name) : KListView(parent, name)
 {
-	config = kapp->getConfig();
+	config = kapp->config();
 
 	selectedItem = 0;
 
@@ -152,14 +149,15 @@ FaxView::FaxView(QWidget *parent, const char *name) : QListView(parent, name)
 	setMinimumSize(sizeHint());
 	setSorting(0, false);
 	setAllColumnsShowFocus(true);
+	setShowSortIndicator(true);
 
 	contextMenu = new QPopupMenu(0, "contextmenu");
 	CHECK_PTR(contextMenu);
-	contextMenu->insertItem(Icon("print_preview.xpm"), i18n("&View..."), ID_FILE_VIEW);
-	contextMenu->insertItem(Icon("fileprint.xpm"), i18n("&Print..."), ID_FILE_PRINT);
-	contextMenu->insertItem(Icon("filefloppy.xpm"), i18n("&Export..."), ID_FILE_EXPORT);
-	contextMenu->insertItem(Icon("filemail.xpm"), i18n("&Mail..."), ID_FILE_MAIL);
-	contextMenu->insertItem(Icon("filedel.xpm"), i18n("De&lete"), ID_FILE_DELETE);
+	contextMenu->insertItem(SmallIcon("viewmag"), i18n("&View..."), ID_FILE_VIEW);
+	contextMenu->insertItem(SmallIcon("fileprint"), i18n("&Print..."), ID_FILE_PRINT);
+	contextMenu->insertItem(SmallIcon("filesave"), i18n("&Export..."), ID_FILE_EXPORT);
+	contextMenu->insertItem(SmallIcon("mail_send"), i18n("&Mail..."), ID_FILE_MAIL);
+	contextMenu->insertItem(SmallIcon("remove"), i18n("De&lete"), ID_FILE_DELETE);
 	contextMenu->insertItem(i18n("&Sender Alias..."), ID_FILE_SENDER_ALIAS);
 
 	connect(this, SIGNAL(selectionChanged(QListViewItem *)), SLOT(selectionChangedSlot(QListViewItem *)));
@@ -168,6 +166,8 @@ FaxView::FaxView(QWidget *parent, const char *name) : QListView(parent, name)
 	connect(this, SIGNAL(rightButtonClicked(QListViewItem *, const QPoint&, int)), SLOT(rightButtonClickedSlot(QListViewItem *, const QPoint&, int)));
 	connect(senderaliases, SIGNAL(applyButtonPressed()), SLOT(refreshAliases()));
 	connect(contextMenu, SIGNAL(activated(int)), SLOT(contextMenuSlot(int)));
+
+	setMinimumSize(40, 30);
 }
 
 
@@ -365,7 +365,7 @@ QString FaxView::selectedFaxName()
 	if (selectedItem)
 		return selectedItem->name();
 
-	return QString(0);
+	return QString::null;
 }
 
 
@@ -383,7 +383,7 @@ QString FaxView::selectedFaxAlias()
 	if (selectedItem)
 		return selectedItem->alias();
 
-	return QString(0);
+	return QString::null;
 }
 
 
