@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@
 #include <qpopupmenu.h>
 #include <qstring.h>
 
+#include <klistview.h>
+
 #include <kconfig.h>
 
 #include "senderaliases.h"
@@ -50,7 +52,7 @@ public:
 	FaxViewItem(QListView *parent = 0, const char *name = 0);
 	virtual ~FaxViewItem();
 
-	void setName(const QString& name);
+	void setName(const QString& name_);
 	QString name();
 	void setNew(bool isnew);
 	bool isNew();
@@ -99,12 +101,12 @@ inline QString FaxViewItem::alias()
 
 
 
-class FaxView : public QListView
+class FaxView : public KListView
 {
 	Q_OBJECT
 public:
 	FaxView(QWidget *parent = 0, const char *name = 0);
-	~FaxView();
+	virtual ~FaxView();
 
 	void readOptions();
 	void saveOptions();
@@ -145,8 +147,6 @@ signals:
 private:
 	KConfig *config;
 
-	bool got_tooltips;
-
 	FaxViewItem *selectedItem;
 
 	QPopupMenu *contextMenu;
