@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,15 +27,19 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <qregexp.h>
-#include <qdir.h>
+#include <qdatetime.h>
 
-#include <kapp.h>
+#include <kstddirs.h>
+#include <klocale.h>
+#include <kglobal.h>
 
 #include "global.h"
 
 
 
+bool got_sigpipe = false;
+
+
 const uchar xchg_endian[256] = {
 	0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
 	0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
@@ -72,65 +76,24 @@ const uchar xchg_endian[256] = {
 };
 
 
-bool testDir(const char *path)
+QString expandPath(const QString& fname)
 {
-	QString s;
-	QDir d;
-
-	s = kapp->localkdedir() + "/" + path;
-	d.setPath((const char *)s);
-	if (!d.exists())
-		return d.mkdir((const char *)s);
-
-	return true;
-}
-
-
-QString expandPath(const char *fname)
-{
-	QString s;
-	
-	return s.sprintf("%s/%s/%s", (const char *)kapp->localkdedir(), KMLOFAX_DIR, fname);
+	return locateLocal("appdata", fname);
 }
 
 
 QString mloDateStr(const char *name)
 {
-	char buffer[15], c;
-	QString s;
+	int year, month, day, hour, minute, second;
+	QDate date;
+	QTime time;
 
-	strncpy(buffer, name, 14);
-	buffer[14] = 0;
+	mloDateSplit(name, &year, &month, &day, &hour, &minute, &second);
+	
+	date.setYMD(year, month, day);
+	time.setHMS(hour, minute, second);
 
-	c = buffer[4];
-	buffer[4] = 0;
-	s = buffer;
-	buffer[4] = c;
-	s += "-";
-	c = buffer[6];
-	buffer[6] = 0;
-	s += &(buffer[4]);
-	buffer[6] = c;
-	s += "-";
-	c = buffer[8];
-	buffer[8] = 0;
-	s += &(buffer[6]);
-	buffer[8] = c;
-	s += " (";
-	c = buffer[10];
-	buffer[10] = 0;
-	s += &(buffer[8]);
-	buffer[10] = c;
-	s += ":";
-	c = buffer[12];
-	buffer[12] = 0;
-	s += &(buffer[10]);
-	buffer[12] = c;
-	s += ":";
-	s += &(buffer[12]);
-	s += ")";
-
-	return s;
+	return KGlobal::locale()->formatDate(date, true) + " (" + KGlobal::locale()->formatTime(time, true) + ")";
 }
 
 
