@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
     ELSA and MicroLink are trademarks of ELSA AG, Aachen.
 */
 
-
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
@@ -43,7 +42,6 @@
 #define PAPER_EXECUTIVE 5
 
 
-#define KMLOFAX_DIR						"share/apps/kmlofax"
 #define KMLOFAX_FAXDIR				"facsimilerc"
 #define KMLOFAX_ALIASLIST			"aliasesrc"
 
@@ -105,10 +103,11 @@
 #define ID_FILE_REBUILD_DIRECTORY  10090
 #define ID_FILE_QUIT               10100
 
-#define ID_OPTIONS_PREFERENCES     11010
-#define ID_OPTIONS_SENDER_ALIASES  11020
-#define ID_OPTIONS_TOOLBAR         11030
-#define ID_OPTIONS_STATUSBAR       11040
+#define ID_SETTINGS_TOOLBAR        11010
+#define ID_SETTINGS_STATUSBAR      11020
+#define ID_SETTINGS_SAVEOPTIONS    11030
+#define ID_SETTINGS_SENDER_ALIASES 11040
+#define ID_SETTINGS_CONFIGURE      11050
 
 #define ID_HELP_CONTENTS           1002
 #define ID_HELP_ABOUT              1003
@@ -116,16 +115,12 @@
 #define ID_STATUS_MSG              1001
 
 
-
-#define SENDER_ALIAS(x) (senderaliases->alias(x))
-
-
+extern bool got_sigpipe;
 
 extern const uchar xchg_endian[];
 
-bool testDir(const char *path);
 
-QString expandPath(const char *fname);
+QString expandPath(const QString& fname);
 
 QString mloDateStr(const char *name);
 
