@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,8 +34,9 @@
 #include <qstring.h>
 #include <qpopupmenu.h>
 
-#include <kapp.h>
-#include <ktmainwindow.h>
+#include <kuniqueapp.h>
+#include <klocale.h>
+#include <kmainwindow.h>
 #include <kconfig.h>
 #include <kaccel.h>
 
@@ -46,10 +47,11 @@
 #include <X11/Xlib.h>
 
 
-class KMLOFaxApp : public KApplication
+
+class KMLOFaxApp : public KUniqueApplication
 {
 public:
-	KMLOFaxApp(int& argc, char **argv, const QString& rAppName);
+	KMLOFaxApp();
 	virtual ~KMLOFaxApp();
 
 protected:
@@ -58,12 +60,12 @@ protected:
 
 
 
-class KMLOFax : public KTMainWindow
+class KMLOFax : public KMainWindow
 {
 	Q_OBJECT
 public:
-	KMLOFax(const char *name = 0);
-	~KMLOFax();
+	KMLOFax(QWidget *parent = 0, const char *name = 0);
+	virtual ~KMLOFax();
 
 	void enableCommand(int id_, bool enable);
 
@@ -75,6 +77,7 @@ protected:
 	void initToolBar();
 	void initStatusBar();
 	void initKeyAccel();
+	void initWhatsThis();
 
 	virtual bool queryClose();
 
@@ -92,17 +95,17 @@ public slots:
 	void slotFileRebuildDir();
 	void slotFileQuit();
 
-	void slotOptionsPreferences();
-	void slotOptionsSenderAliases();
-	void slotOptionsShowToolbar();
-	void slotOptionsShowStatusbar();
+	void slotSettingsShowToolbar();
+	void slotSettingsShowStatusbar();
+	void slotSettingsConfigure();
+	void slotSettingsSenderAliases();
 
 	void slotStatusMsg(const QString& text);
 	void slotStatusHelpMsg(const QString& text);
 	
 private slots:
-	void newPrefs();
-	void gotSelection(bool on);
+	void slotNewConfig();
+	void hasSelectionSlot(bool on);
 	void fetchFile(const QString& name);
 	void fetchDone();
 
@@ -112,8 +115,9 @@ private:
 	KAccel *keyAccel;
 
 	QPopupMenu *fileMenu;
-	QPopupMenu *optionsMenu;
-	QPopupMenu *helpMenu;
+	QPopupMenu *moveMenu;
+	QPopupMenu *settingsMenu;
+	QPopupMenu *helpMenu_;
 	
 	FaxView *view;
 	Preview *preview;
