@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,20 +36,20 @@
 #include <qfont.h>
 #include <qpushbutton.h>
 #include <qtooltip.h>
-#include <qstring.h>
 
 #include <kapp.h>
-#include <kmsgbox.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <kseparator.h>
 
 #include "maildlg.h"
 #include "filters.h"
+#include "mlofile.h"
+#include "senderaliases.h"
 #include "global.h"
 
 
 
-MailDlg *maildlg = 0;
-
-
 
 MailClient::MailClient() : DwSmtpClient()
 {
@@ -189,7 +189,7 @@ bool MailClient::sendFile(FILE *stream)
 
 	prog = new QProgressDialog(i18n("Sending mail..."), i18n("Cancel"), (int)ftell(stream), 0, "mailprogress", true);
 	CHECK_PTR(prog);
-	prog->setCaption(i18n("Sending Mail"));
+	prog->setCaption(i18n("Mail Sending"));
 
 	rewind(stream);
 	prog->setProgress(0);
@@ -232,26 +232,25 @@ void MailClient::disconnect()
 
 
 
-MailDlg::MailDlg(QWidget *parent, const char *name) : QDialog (parent, name)
+MailDlg::MailDlg(QWidget *parent, const char *name) : KDialog (parent, name, true)
 {
 	QVBoxLayout *vbox;
 	QHBoxLayout *hbox;
 	QGroupBox *gb;
 	QGridLayout *grid;
 	QLabel *label;
-	QPushButton *ok, *cancel;
+	QPushButton *help, *send, *cancel;
 	QSize size;
 	QFont font;
+	KSeparator *separator;
 
-	config = kapp->getConfig();
+	config = kapp->config();
 	
-	gotToolTips = false;
-
-	vbox = new QVBoxLayout(this, 8);
+	vbox = new QVBoxLayout(this, marginHint());
 
 	gb = new QGroupBox(this);
 
-	grid = new QGridLayout(gb, 2, 2, 8);
+	grid = new QGridLayout(gb, 2, 2, marginHint());
 
 	label = new QLabel(i18n("&To:"), gb);
 	label->setMinimumSize(label->sizeHint());
@@ -280,37 +279,57 @@ MailDlg::MailDlg(QWidget *parent, const char *name) : QDialog (parent, name)
 
 	grid->activate();
 
-	vbox->addWidget(gb, 0);
+	vbox->addWidget(gb);
 
 	body = new QMultiLineEdit(this);
 	body->setFont(font);
 	
 	vbox->addWidget(body, 1);
 
-	hbox = new QHBoxLayout(8);
+	label = new QLabel(QString("%1: facsimile.ps (application/postscript)").arg(i18n("Attachment")), this);
+	label->setMinimumSize(label->sizeHint());
+	label->setFrameStyle(QFrame::Panel|QFrame::Sunken);
+	
+	vbox->addWidget(label);
+
+	separator = new KSeparator(KSeparator::HLine, this);
+	vbox->addWidget(separator);
+	
+	hbox = new QHBoxLayout();
 	vbox->addLayout(hbox);
 
-	ok = new QPushButton(i18n("OK"), this);
-	ok->setDefault(true);
+	help = new QPushButton(i18n("&Help"), this);
+	send = new QPushButton(i18n("&Send"), this);
+	send->setDefault(true);
+	cancel = new QPushButton(i18n("&Cancel"), this);
 
-	cancel = new QPushButton(i18n("Cancel"), this);
+	size = help->sizeHint().expandedTo(send->sizeHint().expandedTo(cancel->sizeHint()));
 
-	size = ok->sizeHint();
-	size = size.expandedTo(cancel->sizeHint());
-
-	ok->setFixedSize(size);
+	help->setFixedSize(size);
+	send->setFixedSize(size);
 	cancel->setFixedSize(size);
 
-	hbox->addStretch(1);
-	hbox->addWidget(ok);
+	hbox->addWidget(help);
+	hbox->addStretch();
+	hbox->addWidget(send);
 	hbox->addWidget(cancel);
 
 	vbox->activate();
 
-	connect(ok, SIGNAL(clicked()), SLOT(okClicked()));
+	config->setGroup(ID_PREF_GROUP_GENERAL);
+	if (config->readBoolEntry(ID_PREF_GEN_TOOLTIPS, PREF_GEN_TOOLTIPS)) {
+		QToolTip::add(header_to, i18n("Email address of the receiver"));
+		QToolTip::add(header_subject, i18n("Subject of the email"));
+		QToolTip::add(body, i18n("Body of the email"));
+	}
+
+	connect(help, SIGNAL(clicked()), SLOT(slotHelp()));
+	connect(send, SIGNAL(clicked()), SLOT(slotSend()));
 	connect(cancel, SIGNAL(clicked()), SLOT(reject()));
 
-	setCaption(i18n("KMLOFax Mail"));
+	resize(400, 300);
+
+	setCaption(i18n("Mail"));
 }
 
 
@@ -319,48 +338,35 @@ MailDlg::~MailDlg()
 }
 
 
-void MailDlg::addToolTips(bool on)
+void MailDlg::mailFax(const QString& name)
 {
-	if (on == gotToolTips)
-		return;
-
-	gotToolTips = on;
-
-	if (gotToolTips) {
-		QToolTip::add(header_to, i18n("Email address of the receiver"));
-		QToolTip::add(header_subject, i18n("Subject of the email"));
-		QToolTip::add(body, i18n("Body of the email"));
+	QString sender;
+	MLOFile mlofile;
+	
+	mlofile.setName(name);
+	if (mlofile.open()) {
+		sender = SENDER_ALIAS(mlofile.sender());
+		mlofile.close();
 	}
-	else {
-		QToolTip::remove(header_to);
-		QToolTip::remove(header_subject);
-		QToolTip::remove(body);
-	}
-}	
+	
+	m_name = name;
 
-
-void MailDlg::mailFax(const QString& name, const QString& alias)
-{
-	QString s;
-
-	fname = name;
-	salias = alias;
-
-	if (alias.isEmpty())
-		s = i18n("Facsimile");
+	if (sender.isEmpty())
+		header_subject->setText(i18n("Facsimile"));
 	else
-		s.sprintf(i18n("Facsimile from %s"), (const char *)salias);
-	header_subject->setText(s);
+		header_subject->setText(i18n("Facsimile from %1").arg(sender));
+	
 	body->setText(i18n("This is a facsimile file forwarded with KMLOFax."));
-
-	if (isVisible())
-		raise();
-	else
-		show();
 }
 
 
-void MailDlg::okClicked()
+void MailDlg::slotHelp()
+{
+	kapp->invokeHelp("MAIL-HELP");
+}
+
+
+void MailDlg::slotSend()
 {
 	MailClient mclient;
 	QString from, server, name, org, email, reply;
@@ -377,22 +383,22 @@ void MailDlg::okClicked()
 	reply = config->readEntry(ID_PREF_MAIL_REPLY, PREF_MAIL_REPLY);
 	
 	if (server.isEmpty()) {
-		KMsgBox::message(0, i18n("Mail Error"), i18n("No SMTP server specified."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("No SMTP server specified."), i18n("Mail Error"));
 		return;
 	}
 
 	if (email.isEmpty()) {
-		KMsgBox::message(0, i18n("Mail Error"), i18n("No sender specified."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("No sender specified."), i18n("Mail Error"));
 		return;
 	}
 
 	if (!*(header_to->text())) {
-		KMsgBox::message(0, i18n("Mail Error"), i18n("No receiver specified."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("No receiver specified."), i18n("Mail Error"));
 		return;
 	}
 
 	if (!mclient.connect(server, port)) {
-		KMsgBox::message(0, i18n("SMTP Error"), i18n("Cannot connect to server."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot connect to server."), i18n("SMTP Error"));
 		return;
 	}
 
@@ -407,36 +413,36 @@ void MailDlg::okClicked()
 	}
 
 	if (!mclient.sendHeader(from.data(), header_to->text(), header_subject->text())) {
-		KMsgBox::message(0, i18n("SMTP Error"), i18n("Cannot send mail header."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot send mail header."), i18n("SMTP Error"));
 		mclient.disconnect();
 		return;
 	}
 
 	if (!mclient.sendBody(body->text().data())) {
-		KMsgBox::message(0, i18n("SMTP Error"), i18n("Cannot send mail body."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot send mail body."), i18n("SMTP Error"));
 		mclient.disconnect();
 		return;
 	}
 
 	if (!(f = tmpfile())) {
-		KMsgBox::message(0, i18n("File Error"), i18n("Cannot create temporary file."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot create temporary file."), i18n("SMTP Error"));
 		mclient.disconnect();
 		return;
 	}
 	
-	filter.setFile(fname);
+	filter.setFile(m_name);
 	
-	if (!filter.convertFile(f, salias)) {
+	if (!filter.convertFile(f)) {
 		fclose(f);
 		mclient.disconnect();
 		return;
 	}
 
 	if (!mclient.sendFile(f)) {
-		KMsgBox::message(0, i18n("SMTP Error"), i18n("Cannot send file."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot send file."), i18n("SMTP Error"));
 	}
 
 	mclient.disconnect();
 
-	hide();
+	accept();
 }
