@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <o.gantz@tu-bs.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,11 +33,12 @@
 
 #include <stdio.h>
 
-#include <qdialog.h>
 #include <qwidget.h>
 #include <qlineedit.h>
 #include <qmultilinedit.h>
+#include <qstring.h>
 
+#include <kdialog.h>
 #include <kconfig.h>
 
 #include <mimelib/smtp.h>
@@ -69,33 +70,28 @@ private:
 
 
 
-class MailDlg : public QDialog
+class MailDlg : public KDialog
 {
 	Q_OBJECT
 public:
 	MailDlg(QWidget *parent = 0, const char *name = 0);
 	~MailDlg();
 
-	void addToolTips(bool on);
+	void mailFax(const QString& name);
 
-	void mailFax(const QString& name, const QString& alias);
-
-private slots:
-	void okClicked();
+protected slots:
+	void slotHelp();
+	void slotSend();
 
 private:
 	KConfig *config;
 	
-	bool gotToolTips;
-
 	QLineEdit *header_to;
 	QLineEdit *header_subject;
 	QMultiLineEdit *body;
 
-	QString fname, salias;
+	QString m_name;
 };
 
 
-extern MailDlg *maildlg;
-
 #endif // MAILDLG_H
