@@ -1,10 +1,10 @@
 /*
     KMLOFax
-    
-    A utility to process facsimile received with the ELSA
+
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,70 +24,51 @@
     ELSA and MicroLink are trademarks of ELSA AG, Aachen.
 */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif 
-
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <signal.h>
 
-#include <qglobal.h>
-
-#include <kapp.h>
-#include <ktmainwindow.h>
+#include <kuniqueapp.h>
+#include <kcmdlineargs.h>
+#include <kaboutdata.h>
+#include <klocale.h>
 
 #include "kmlofax.h"
 #include "global.h"
 
 
+static const char *description =
+	I18N_NOOP("A facsimile utility for the ELSA MicroLink(tm) Office modem.");
+	
+	
 
-void sighandler(int sig)
+static void sighandler(int)
 {
+	got_sigpipe = true;
 	signal(SIGPIPE, sighandler);
 }
 
 
-void print_version()
-{
-	fprintf(stderr, "kmlofax %s\n", VERSION);
-}
-
-
-void print_help()
-{
-	fprintf(stderr, "Usage: kmlofax [-help] [-version] [generic Qt or KDE arguments]\n");
-}
-
-
 int main(int argc, char *argv[])
 {
-	int i;
-
-	for (i=1; i < argc; i++) {
-		if (strcmp(argv[i], "-help") == 0) {
-			print_help();
-			exit(1);
-		}
-		else if (strcmp(argv[i], "-version") == 0) {
-			print_version();
-			exit(1);
-		}
-	}
-
-	testDir("share");
-	testDir("share/apps");
-	testDir("share/apps/kmlofax");
+	KAboutData aboutData("kmlofax", I18N_NOOP("KMLOFax"),
+		VERSION, description, KAboutData::License_GPL,
+		"(c) 1999-2001, Oliver Gantz",
+		I18N_NOOP("ELSA and MicroLink are trademarks of ELSA AG, Aachen."),
+		"http://www.tu-bs.de/~y0000441/kmlofax.html",
+		"Oliver.Gantz@ePost.de");
+	aboutData.addAuthor("Oliver Gantz", 0, "Oliver.Gantz@ePost.de");
+	KCmdLineArgs::init(argc, argv, &aboutData);
 
 	signal(SIGPIPE, sighandler);
 
-	KMLOFaxApp a(argc, argv, "kmlofax");
-	KMLOFax *kmlofax = new KMLOFax("kmlofaxtop");
-	CHECK_PTR(kmlofax);
+	if (!KUniqueApplication::start())
+		exit(0);
 
+	KMLOFaxApp a;
+	KMLOFax *kmlofax = new KMLOFax(0, "mainwindow");
+	CHECK_PTR(kmlofax);
 	a.setMainWidget(kmlofax);
-	kmlofax->show();
+	kmlofax->setCaption(QString::null);
 
 	return a.exec();
 }
