@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,14 +30,17 @@
 #include <qscrollbar.h>
 
 #include <kapp.h>
+#include <klocale.h>
 #include <kiconloader.h>
-#include <kmsgbox.h>
+#include <kmessagebox.h>
+#include <kmenubar.h>
 
 #include "preview.h"
 #include "mlofile.h"
 #include "printdlg.h"
 #include "exportdlg.h"
 #include "maildlg.h"
+#include "senderaliases.h"
 #include "global.h"
 
 #include <X11/Xlib.h>
@@ -78,7 +81,7 @@ char *shrinkPage(int w, int h, char *data)
 
 	bpl = (((w-1) >> 4) + 1) << 1;
 	nbpl = (((nw-1) >> 4) + 1) << 1;
-	ndata = (char *)malloc(nbpl * nh);
+	ndata = (char *)malloc(nbpl *nh);
 
 	line = (uchar *)data;
 	nline = (uchar *)ndata;
@@ -153,7 +156,8 @@ char *rotatePage(int w, int h, char *data, bool lsb_first)
 }
 
 
-FaxWidget::FaxWidget(QWidget *parent, const char *name, WFlags f) : QWidget(parent, name, f)
+
+FaxWidget::FaxWidget(QWidget *parent, const char *name) : QWidget(parent, name)
 {
 	int screen;
 
@@ -217,7 +221,7 @@ void FaxWidget::setImage(int w, int h, char *data)
 		XResizeWindow(display, window, 1, 1);
 	}
 
-	updateRects();
+	updateGeometry();
 
 	repaint(false);
 }
@@ -233,11 +237,59 @@ void FaxWidget::deleteImage()
 }
 
 
+void FaxWidget::updateGeometry()
+{
+	int w, h, range;
+	bool need_hscroll, need_vscroll;
+
+	w = width();
+	h = height();
+
+	if ((need_hscroll = (im_width > w)))
+		h -= hscroll->height();
+	if ((need_vscroll = (im_height > h))) {
+		w -= vscroll->width();
+		if (!need_hscroll && (im_width > w)) {
+			need_hscroll = true;
+			h -= hscroll->height();
+		}
+	}
+	
+	if (need_hscroll) {
+		range = im_width - w;
+		hscroll->setRange(0, range);
+		if (hscroll->value() > range)
+			hscroll->setValue(range);
+		hscroll->setSteps(12, w);
+		hscroll->setGeometry(0, h, w, hscroll->height());
+		hscroll->show();
+	} else {
+		hscroll->hide();
+		hscroll->setRange(0, 0);
+		hscroll->setValue(0);
+	}
+	
+	if (need_vscroll) {
+		range = im_height - h;
+		vscroll->setRange(0, range);
+		if (vscroll->value() > range)
+			vscroll->setValue(range);
+		vscroll->setSteps(12, h);
+		vscroll->setGeometry(w, 0, vscroll->width(), h);
+		vscroll->show();
+	} else {
+		vscroll->hide();
+		vscroll->setRange(0, 0);
+		vscroll->setValue(0);
+	}
+}
+
+
 bool FaxWidget::x11EventFilter(XEvent *ev)
 {
 	bool refresh = false;
 	bool move_it = false;
-	int mv_x = 0, mv_y = 0;
+	int mv_x = 0, mv_y = 0, wheel_steps = 0, wheel_state = 0;
 	int x1 = INT_MAX, y1 = INT_MAX, x2 = 0, y2 = 0, xb, yb;
 
 	if (ev->xany.window != window)
@@ -252,6 +304,24 @@ bool FaxWidget::x11EventFilter(XEvent *ev)
 					move_x = ev->xbutton.x;
 					move_y = ev->xbutton.y;
 				}
+				if ((ev->xbutton.button == Button4) || (ev->xbutton.button == Button5)) {
+					if (ev->xbutton.state & Button1Mask)
+						wheel_state |= Qt::LeftButton;
+					if (ev->xbutton.state & Button2Mask)
+						wheel_state |= Qt::MidButton;
+					if (ev->xbutton.state & Button3Mask)
+						wheel_state |= Qt::RightButton;
+					if (ev->xbutton.state & ShiftMask)
+						wheel_state |= Qt::ShiftButton;
+					if (ev->xbutton.state & ControlMask)
+						wheel_state |= Qt::ControlButton;
+					if (ev->xbutton.state & Mod1Mask)
+						wheel_state |= Qt::AltButton;
+					if (ev->xbutton.button == Button4)
+						wheel_steps++;
+					else
+						wheel_steps--;
+				}
 				break;
 			case ButtonRelease:
 				if (ev->xbutton.button == Button1) {
@@ -293,6 +363,11 @@ bool FaxWidget::x11EventFilter(XEvent *ev)
 		move_y = mv_y;
 	}
 
+	if (wheel_steps) {
+		QWheelEvent e(QPoint(0, 0), 120 * wheel_steps, wheel_state);
+		KApplication::sendEvent(vscroll, &e);
+	}
+
 	return true;
 }	
 
@@ -388,58 +463,15 @@ void FaxWidget::paintEvent(QPaintEvent *)
 
 void FaxWidget::resizeEvent(QResizeEvent *)
 {
-	updateRects();
+	updateGeometry();
 }
 
 
-void FaxWidget::updateRects()
-{
-	int w, h;
-	bool need_hscroll, need_vscroll;
-
-	w = width();
-	h = height();
-
-	if ((need_hscroll = (im_width > w)))
-		h -= hscroll->height();
-	if ((need_vscroll = (im_height > h))) {
-		w -= vscroll->width();
-		if (!need_hscroll && (im_width > w)) {
-			need_hscroll = true;
-			h -= hscroll->height();
-		}
-	}
-	
-	if (need_hscroll) {
-		hscroll->setRange(0, im_width - w);
-		hscroll->setSteps(12, w);
-		hscroll->setGeometry(0, h, w, hscroll->height());
-		hscroll->show();
-	} else {
-		hscroll->hide();
-		hscroll->setRange(0, 0);
-		hscroll->setValue(0);
-	}
-	
-	if (need_vscroll) {
-		vscroll->setRange(0, im_height - h);
-		vscroll->setSteps(12, h);
-		vscroll->setGeometry(w, 0, vscroll->width(), h);
-		vscroll->show();
-	} else {
-		vscroll->hide();
-		vscroll->setRange(0, 0);
-		vscroll->setValue(0);
-	}
-}
-
-
-
-Preview::Preview(const char *name) : KTMainWindow(name)
+Preview::Preview(QWidget *parent, const char *name) : KMainWindow(parent, name, WType_TopLevel)
 {
 	int i;
 
-	config = kapp->getConfig();
+	config = kapp->config();
 	
 	for (i=0; i < 3; i++)
 		page_datas[i] = 0;
@@ -456,13 +488,13 @@ Preview::Preview(const char *name) : KTMainWindow(name)
 	view = new FaxWidget(this, "faxwidget");
 	CHECK_PTR(view);
 	fw = view;
-	setView(view);
+	setCentralWidget(view);
 	
 	initKeyAccel();
 
 	readOptions();
 
-	setCaption(i18n("KMLOFax Preview"));
+	setCaption(i18n("Preview"));
 }
 
 
@@ -472,25 +504,23 @@ Preview::~Preview()
 }
 
 
-void Preview::showFax(const QString& name, const QString& alias)
+void Preview::showFax(const QString& name)
 {
 	slotStatusName("");
 	slotStatusSender("");
 
 	file.setName(name);
 	if (!file.open()) {
-		KMsgBox::message(0, i18n("File Error"), i18n("Cannot open facsimile file."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot open facsimile file."), i18n("File Error"));
 		return;
 	}
 	pages = file.pages();
+	slotStatusName(name);
+	slotStatusSender(SENDER_ALIAS(file.sender()));
 	file.close();
 
-	fname = name;
-	salias = alias;
+	m_name = name;
 	
-	slotStatusName(fname);
-	slotStatusSender(salias);
-
 	loadPage(1);
 
 	if (isVisible())
@@ -512,17 +542,15 @@ void Preview::readOptions()
 	config->setGroup("Preview Options");
 
 	bool toolBarOn = config->readBoolEntry("Show ToolBar", true);
-	optionsMenu->setItemChecked(ID_PRE_OPTIONS_TOOLBAR, toolBarOn);
+	settingsMenu->setItemChecked(ID_PRE_SETTINGS_TOOLBAR, toolBarOn);
 	if (!toolBarOn)
-		enableToolBar(KToolBar::Hide);
+		toolBar()->hide();
 
 	bool statusBarOn = config->readBoolEntry("Show StatusBar", true);
-	optionsMenu->setItemChecked(ID_PRE_OPTIONS_STATUSBAR, statusBarOn);
+	settingsMenu->setItemChecked(ID_PRE_SETTINGS_STATUSBAR, statusBarOn);
 	if (!statusBarOn)
-		enableStatusBar(KStatusBar::Hide);
+		statusBar()->hide();
 
-	menuBar()->setMenuBarPos((KMenuBar::menuPosition)config->readNumEntry("MenuBarPos", (int)KMenuBar::Top));
-	
 	toolBar()->setBarPos((KToolBar::BarPosition)config->readNumEntry("ToolBarPos", (int)KToolBar::Top));
 	
 	QSize geoSize(650, 400);
@@ -537,7 +565,6 @@ void Preview::saveOptions()
 	config->writeEntry("Geometry", size());
 	config->writeEntry("Show ToolBar", toolBar()->isVisible());
 	config->writeEntry("Show StatusBar", statusBar()->isVisible());
-	config->writeEntry("MenuBarPos", (int)menuBar()->menuBarPos());
 	config->writeEntry("ToolBarPos", (int)toolBar()->barPos());
 }
 
@@ -546,60 +573,62 @@ void Preview::initMenuBar()
 {
 	fileMenu = new QPopupMenu(0, "prefilemenu");
 	CHECK_PTR(fileMenu);
-	fileMenu->insertItem(Icon("fileprint.xpm"), i18n("&Print..."), ID_PRE_FILE_PRINT);
-	fileMenu->insertItem(Icon("filefloppy.xpm"), i18n("&Export..."), ID_PRE_FILE_EXPORT);
-	fileMenu->insertItem(Icon("filemail.xpm"), i18n("&Mail..."), ID_PRE_FILE_MAIL);
+	fileMenu->insertItem(SmallIcon("fileprint"), i18n("&Print..."), ID_PRE_FILE_PRINT);
+	fileMenu->insertItem(SmallIcon("filesave"), i18n("&Export..."), ID_PRE_FILE_EXPORT);
+	fileMenu->insertItem(SmallIcon("mail_send"), i18n("&Mail..."), ID_PRE_FILE_MAIL);
 	fileMenu->insertSeparator();
-	fileMenu->insertItem(i18n("&Close"), ID_PRE_FILE_CLOSE);
+	fileMenu->insertItem(SmallIcon("fileclose"), i18n("&Close"), ID_PRE_FILE_CLOSE);
 
-	gotoMenu = new QPopupMenu(0, "pregotomenu");
-	CHECK_PTR(gotoMenu);
-	gotoMenu->insertItem(Icon("back.xpm"), i18n("&Previous Page"), ID_PRE_GOTO_PREVIOUS);
-	gotoMenu->insertItem(Icon("forward.xpm"), i18n("&Next Page"), ID_PRE_GOTO_NEXT);
-	gotoMenu->insertItem(Icon("start.xpm"), i18n("&First Page"), ID_PRE_GOTO_FIRST);
-	gotoMenu->insertItem(Icon("finish.xpm"), i18n("&Last Page"), ID_PRE_GOTO_LAST);
-	
 	viewMenu = new QPopupMenu(0, "previewmenu");
 	CHECK_PTR(viewMenu);
-	viewMenu->insertItem(Icon("viewmag+.xpm"), i18n("Zoom &In"), ID_PRE_VIEW_ZOOM_IN);
-	viewMenu->insertItem(Icon("viewmag-.xpm"), i18n("Zoom &Out"), ID_PRE_VIEW_ZOOM_OUT);
-	viewMenu->insertItem(Icon("rotate.xpm"), i18n("&Rotate"), ID_PRE_VIEW_ROTATE);
+	viewMenu->insertItem(SmallIcon("viewmag+"), i18n("Zoom &In"), ID_PRE_VIEW_ZOOM_IN);
+	viewMenu->insertItem(SmallIcon("viewmag-"), i18n("Zoom &Out"), ID_PRE_VIEW_ZOOM_OUT);
+	viewMenu->insertItem(SmallIcon("rotate"), i18n("&Rotate"), ID_PRE_VIEW_ROTATE);
 
-	optionsMenu = new QPopupMenu(0, "preoptmenu");
-	CHECK_PTR(optionsMenu);
-	optionsMenu->setCheckable(true);
-	optionsMenu->insertItem(i18n("Show &Toolbar"), ID_PRE_OPTIONS_TOOLBAR);
-	optionsMenu->setItemChecked(ID_PRE_OPTIONS_TOOLBAR, true);
-	optionsMenu->insertItem(i18n("Show Status&bar"), ID_PRE_OPTIONS_STATUSBAR);
-	optionsMenu->setItemChecked(ID_PRE_OPTIONS_STATUSBAR, true);
+	goMenu = new QPopupMenu(0, "pregomenu");
+	CHECK_PTR(goMenu);
+	goMenu->insertItem(SmallIcon("back"), i18n("&Previous Page"), ID_PRE_GO_PREVIOUS);
+	goMenu->insertItem(SmallIcon("forward"), i18n("&Next Page"), ID_PRE_GO_NEXT);
+	goMenu->insertItem(SmallIcon("start"), i18n("&First Page"), ID_PRE_GO_FIRST);
+	goMenu->insertItem(SmallIcon("finish"), i18n("&Last Page"), ID_PRE_GO_LAST);
+	
+	settingsMenu = new QPopupMenu(0, "presettingsmenu");
+	CHECK_PTR(settingsMenu);
+	settingsMenu->setCheckable(true);
+	settingsMenu->insertItem(i18n("Show &Toolbar"), ID_PRE_SETTINGS_TOOLBAR);
+	settingsMenu->setItemChecked(ID_PRE_SETTINGS_TOOLBAR, true);
+	settingsMenu->insertItem(i18n("Show &Statusbar"), ID_PRE_SETTINGS_STATUSBAR);
+	settingsMenu->setItemChecked(ID_PRE_SETTINGS_STATUSBAR, true);
+	settingsMenu->insertSeparator();
+	settingsMenu->insertItem(i18n("Save &Options"), ID_PRE_SETTINGS_SAVEOPTIONS);
 
 	menuBar()->insertItem(i18n("&File"), fileMenu);
-	menuBar()->insertItem(i18n("&Goto"), gotoMenu);
 	menuBar()->insertItem(i18n("&View"), viewMenu);
-	menuBar()->insertItem(i18n("&Options"), optionsMenu);
+	menuBar()->insertItem(i18n("&Go"), goMenu);
+	menuBar()->insertItem(i18n("&Settings"), settingsMenu);
 	
 	connect(fileMenu, SIGNAL(activated(int)), SLOT(commandCallback(int)));
-	connect(gotoMenu, SIGNAL(activated(int)), SLOT(commandCallback(int)));
+	connect(goMenu, SIGNAL(activated(int)), SLOT(commandCallback(int)));
 	connect(viewMenu, SIGNAL(activated(int)), SLOT(commandCallback(int)));
-	connect(optionsMenu, SIGNAL(activated(int)), SLOT(commandCallback(int)));
+	connect(settingsMenu, SIGNAL(activated(int)), SLOT(commandCallback(int)));
 }
 
 
 void Preview::initToolBar()
 {
-	toolBar()->insertButton(Icon("back.xpm"), ID_PRE_GOTO_PREVIOUS, true, i18n("Previous Page"));
-	toolBar()->insertButton(Icon("forward.xpm"), ID_PRE_GOTO_NEXT, true, i18n("Next Page"));
-	toolBar()->insertButton(Icon("start.xpm"), ID_PRE_GOTO_FIRST, true, i18n("First Page"));
-	toolBar()->insertButton(Icon("finish.xpm"), ID_PRE_GOTO_LAST, true, i18n("Last Page"));
+	toolBar()->insertButton(BarIcon("fileprint"), ID_PRE_FILE_PRINT, true, i18n("Print Facsimile"));
+	toolBar()->insertButton(BarIcon("filesave"), ID_PRE_FILE_EXPORT, true, i18n("Export Facsimile"));
+	toolBar()->insertButton(BarIcon("mail_send"), ID_PRE_FILE_MAIL, true, i18n("Mail Facsimile"));
 	toolBar()->insertSeparator();
-	toolBar()->insertButton(Icon("viewmag+.xpm"), ID_PRE_VIEW_ZOOM_IN, true, i18n("Zoom In"));
-	toolBar()->insertButton(Icon("viewmag-.xpm"), ID_PRE_VIEW_ZOOM_OUT, true, i18n("Zoom Out"));
-	toolBar()->insertButton(Icon("rotate.xpm"), ID_PRE_VIEW_ROTATE, true, i18n("Rotate"));
+	toolBar()->insertButton(BarIcon("viewmag+"), ID_PRE_VIEW_ZOOM_IN, true, i18n("Zoom In"));
+	toolBar()->insertButton(BarIcon("viewmag-"), ID_PRE_VIEW_ZOOM_OUT, true, i18n("Zoom Out"));
+	toolBar()->insertButton(BarIcon("rotate"), ID_PRE_VIEW_ROTATE, true, i18n("Rotate"));
 	toolBar()->insertSeparator();
-	toolBar()->insertButton(Icon("fileprint.xpm"), ID_PRE_FILE_PRINT, true, i18n("Print Facsimile"));
-	toolBar()->insertButton(Icon("filefloppy.xpm"), ID_PRE_FILE_EXPORT, true, i18n("Export Facsimile"));
-	toolBar()->insertButton(Icon("filemail.xpm"), ID_PRE_FILE_MAIL, true, i18n("Mail Facsimile"));
-	toolBar()->insertButton(Icon("exit.xpm"), ID_PRE_FILE_CLOSE, true, i18n("Close"));
+	toolBar()->insertButton(BarIcon("back"), ID_PRE_GO_PREVIOUS, true, i18n("Previous Page"));
+	toolBar()->insertButton(BarIcon("forward"), ID_PRE_GO_NEXT, true, i18n("Next Page"));
+	toolBar()->insertButton(BarIcon("start"), ID_PRE_GO_FIRST, true, i18n("First Page"));
+	toolBar()->insertButton(BarIcon("finish"), ID_PRE_GO_LAST, true, i18n("Last Page"));
+	toolBar()->insertButton(BarIcon("fileclose"), ID_PRE_FILE_CLOSE, true, i18n("Close"));
 	toolBar()->alignItemRight(ID_PRE_FILE_CLOSE, true);
 	
 	connect(toolBar(), SIGNAL(clicked(int)), SLOT(commandCallback(int)));
@@ -608,15 +637,11 @@ void Preview::initToolBar()
 
 void Preview::initStatusBar()
 {
-	statusBar()->insertItem("00000000000000.FAX", ID_PRE_STATUS_NAME);
-	statusBar()->insertItem(i18n("000000000, Normal"), ID_PRE_STATUS_SIZE);
-	statusBar()->setAlignment(ID_PRE_STATUS_SIZE, AlignHCenter);
-	statusBar()->insertItem(i18n("Page 000 of 000"), ID_PRE_STATUS_PAGE);
-	statusBar()->setAlignment(ID_PRE_STATUS_PAGE, AlignHCenter);
-	statusBar()->insertItem("000", ID_PRE_STATUS_ANGLE);
-	statusBar()->setAlignment(ID_PRE_STATUS_ANGLE, AlignHCenter);
-	statusBar()->insertItem("", ID_PRE_STATUS_SENDER);
-	statusBar()->setAlignment(ID_PRE_STATUS_SENDER, AlignHCenter);
+	statusBar()->insertFixedItem(" 00000000000000.FAX ", ID_PRE_STATUS_NAME);
+	statusBar()->insertFixedItem(i18n(" 000000000, Normal "), ID_PRE_STATUS_SIZE);
+	statusBar()->insertFixedItem(i18n(" Page 000 of 000 "), ID_PRE_STATUS_PAGE);
+	statusBar()->insertFixedItem(" 000 ", ID_PRE_STATUS_ANGLE);
+	statusBar()->insertItem("", ID_PRE_STATUS_SENDER, 1);
 	statusBar()->changeItem("", ID_PRE_STATUS_NAME);
 	statusBar()->changeItem("", ID_PRE_STATUS_SIZE);
 	statusBar()->changeItem("", ID_PRE_STATUS_PAGE);
@@ -632,14 +657,14 @@ void Preview::initKeyAccel()
 	keyAccel->insertItem(i18n("Export File"), "ExportFile", CTRL+Key_E);
 	keyAccel->insertItem(i18n("Mail File"), "MailFile", CTRL+Key_M);
 	
-	keyAccel->insertItem(i18n("Goto Prior"), "GotoPrior", ALT+Key_Left);
-	keyAccel->insertItem(i18n("Goto Next"), "GotoNext", ALT+Key_Right);
-	keyAccel->insertItem(i18n("Goto First"), "GotoFirst", ALT+Key_Up);
-	keyAccel->insertItem(i18n("Goto Last"), "GotoLast", ALT+Key_Down);
+	keyAccel->insertItem(i18n("Go to Previous"), "GoPrevious", CTRL+Key_PageUp);
+	keyAccel->insertItem(i18n("Go to Next"), "GoNext", CTRL+Key_PageDown);
+	keyAccel->insertItem(i18n("Go to First"), "GoFirst", CTRL+Key_Home);
+	keyAccel->insertItem(i18n("Go to Last"), "GoLast", CTRL+Key_End);
 	
-	keyAccel->insertItem(i18n("Zoom In"), "ZoomIn", ALT+Key_Plus);
-	keyAccel->insertItem(i18n("Zoom Out"), "ZoomOut", ALT+Key_Minus);
-	keyAccel->insertItem(i18n("Rotate"), "Rotate", ALT+Key_R);
+	keyAccel->insertItem(i18n("Zoom In"), "ZoomIn", CTRL+Key_Plus);
+	keyAccel->insertItem(i18n("Zoom Out"), "ZoomOut", CTRL+Key_Minus);
+	keyAccel->insertItem(i18n("Rotate"), "Rotate", CTRL+Key_R);
 	
 	keyAccel->insertItem(i18n("Show Toolbar"), "ShowToolbar", CTRL+Key_T);
 	keyAccel->insertItem(i18n("Show Statusbar"), "ShowStatusbar", CTRL+Key_S);
@@ -655,24 +680,24 @@ void Preview::initKeyAccel()
 
 	keyAccel->readSettings();
 
-	keyAccel->connectItem(KAccel::Print, this, SLOT(slotFilePrint()));
+	keyAccel->connectItem(KStdAccel::Print, this, SLOT(slotFilePrint()));
 	keyAccel->connectItem("ExportFile", this, SLOT(slotFileExport()));
 	keyAccel->connectItem("MailFile", this, SLOT(slotFileMail()));
-	keyAccel->connectItem(KAccel::Close, this, SLOT(hide()));
-	
-	keyAccel->connectItem("GotoPrior", this, SLOT(slotGotoPreviousPage()));
-	keyAccel->connectItem("GotoNext", this, SLOT(slotGotoNextPage()));
-	keyAccel->connectItem("GotoFirst", this, SLOT(slotGotoFirstPage()));
-	keyAccel->connectItem("GotoLast", this, SLOT(slotGotoLastPage()));
+	keyAccel->connectItem(KStdAccel::Close, this, SLOT(hide()));
 	
 	keyAccel->connectItem("ZoomIn", this, SLOT(slotViewZoomIn()));
 	keyAccel->connectItem("ZoomOut", this, SLOT(slotViewZoomOut()));
 	keyAccel->connectItem("Rotate", this, SLOT(slotViewRotate()));
 	
-	keyAccel->connectItem("ShowToolbar", this, SLOT(slotOptionsShowToolbar()));
-	keyAccel->connectItem("ShowStatusbar", this, SLOT(slotOptionsShowStatusbar()));
+	keyAccel->connectItem("GoPrevious", this, SLOT(slotGoPreviousPage()));
+	keyAccel->connectItem("GoNext", this, SLOT(slotGoNextPage()));
+	keyAccel->connectItem("GoFirst", this, SLOT(slotGoFirstPage()));
+	keyAccel->connectItem("GoLast", this, SLOT(slotGoLastPage()));
 	
-	keyAccel->connectItem(KAccel::Help, kapp, SLOT(appHelpActivated()));
+	keyAccel->connectItem("ShowToolbar", this, SLOT(slotSettingsShowToolbar()));
+	keyAccel->connectItem("ShowStatusbar", this, SLOT(slotSettingsShowStatusbar()));
+	
+	keyAccel->connectItem(KStdAccel::Help, this, SLOT(appHelpActivated()));
 
 	keyAccel->connectItem("ScrollLeft", view, SLOT(keyLeft()));
 	keyAccel->connectItem("ScrollRight", view, SLOT(keyRight()));
@@ -683,22 +708,22 @@ void Preview::initKeyAccel()
 	keyAccel->connectItem("Home", view, SLOT(keyHome()));
 	keyAccel->connectItem("End", view, SLOT(keyEnd()));
 	
-	keyAccel->changeMenuAccel(fileMenu, ID_PRE_FILE_PRINT, KAccel::Print);
+	keyAccel->changeMenuAccel(fileMenu, ID_PRE_FILE_PRINT, KStdAccel::Print);
 	keyAccel->changeMenuAccel(fileMenu, ID_PRE_FILE_EXPORT, "ExportFile");
 	keyAccel->changeMenuAccel(fileMenu, ID_PRE_FILE_MAIL, "MailFile");
-	keyAccel->changeMenuAccel(fileMenu, ID_PRE_FILE_CLOSE, KAccel::Close);
-	
-	keyAccel->changeMenuAccel(gotoMenu, ID_PRE_GOTO_PREVIOUS, "GotoPrior");
-	keyAccel->changeMenuAccel(gotoMenu, ID_PRE_GOTO_NEXT, "GotoNext");
-	keyAccel->changeMenuAccel(gotoMenu, ID_PRE_GOTO_FIRST, "GotoFirst");
-	keyAccel->changeMenuAccel(gotoMenu, ID_PRE_GOTO_LAST, "GotoLast");
+	keyAccel->changeMenuAccel(fileMenu, ID_PRE_FILE_CLOSE, KStdAccel::Close);
 	
 	keyAccel->changeMenuAccel(viewMenu, ID_PRE_VIEW_ZOOM_IN, "ZoomIn");
 	keyAccel->changeMenuAccel(viewMenu, ID_PRE_VIEW_ZOOM_OUT, "ZoomOut");
 	keyAccel->changeMenuAccel(viewMenu, ID_PRE_VIEW_ROTATE, "Rotate");
 
-	keyAccel->changeMenuAccel(optionsMenu, ID_PRE_OPTIONS_TOOLBAR, "ShowToolbar");
-	keyAccel->changeMenuAccel(optionsMenu, ID_PRE_OPTIONS_STATUSBAR, "ShowStatusbar");
+	keyAccel->changeMenuAccel(goMenu, ID_PRE_GO_PREVIOUS, "GoPrevious");
+	keyAccel->changeMenuAccel(goMenu, ID_PRE_GO_NEXT, "GoNext");
+	keyAccel->changeMenuAccel(goMenu, ID_PRE_GO_FIRST, "GoFirst");
+	keyAccel->changeMenuAccel(goMenu, ID_PRE_GO_LAST, "GoLast");
+	
+	keyAccel->changeMenuAccel(settingsMenu, ID_PRE_SETTINGS_TOOLBAR, "ShowToolbar");
+	keyAccel->changeMenuAccel(settingsMenu, ID_PRE_SETTINGS_STATUSBAR, "ShowStatusbar");
 }
 
 
@@ -717,18 +742,6 @@ void Preview::commandCallback(int id_)
 		case ID_PRE_FILE_CLOSE:
 			hide();
 			break;
-		case ID_PRE_GOTO_PREVIOUS:
-			slotGotoPreviousPage();
-			break;
-		case ID_PRE_GOTO_NEXT:
-			slotGotoNextPage();
-			break;
-		case ID_PRE_GOTO_FIRST:
-			slotGotoFirstPage();
-			break;
-		case ID_PRE_GOTO_LAST:
-			slotGotoLastPage();
-			break;
 		case ID_PRE_VIEW_ZOOM_IN:
 			slotViewZoomIn();
 			break;
@@ -738,11 +751,26 @@ void Preview::commandCallback(int id_)
 		case ID_PRE_VIEW_ROTATE:
 			slotViewRotate();
 			break;
-		case ID_PRE_OPTIONS_TOOLBAR:
-			slotOptionsShowToolbar();
+		case ID_PRE_GO_PREVIOUS:
+			slotGoPreviousPage();
 			break;
-		case ID_PRE_OPTIONS_STATUSBAR:
-			slotOptionsShowStatusbar();
+		case ID_PRE_GO_NEXT:
+			slotGoNextPage();
+			break;
+		case ID_PRE_GO_FIRST:
+			slotGoFirstPage();
+			break;
+		case ID_PRE_GO_LAST:
+			slotGoLastPage();
+			break;
+		case ID_PRE_SETTINGS_TOOLBAR:
+			slotSettingsShowToolbar();
+			break;
+		case ID_PRE_SETTINGS_STATUSBAR:
+			slotSettingsShowStatusbar();
+			break;
+		case ID_PRE_SETTINGS_SAVEOPTIONS:
+			saveOptions();
 			break;
 		default:
 			break;
@@ -752,47 +780,25 @@ void Preview::commandCallback(int id_)
 
 void Preview::slotFilePrint()
 {
-	printdlg->printFax(fname, salias);
+	PrintDlg printdlg(this, "printdlg");
+	printdlg.printFax(m_name);
+	printdlg.exec();
 }
 
 
 void Preview::slotFileExport()
 {
-	exportdlg->exportFax(fname, salias);
+	ExportDlg exportdlg(this, "exportdlg");
+	exportdlg.exportFax(m_name);
+	exportdlg.exec();
 }
 
 
 void Preview::slotFileMail()
 {
-	maildlg->mailFax(fname, salias);
-}
-
-
-void Preview::slotGotoPreviousPage()
-{
-	if (page > 1)
-		loadPage(page-1);
-}
-
-
-void Preview::slotGotoNextPage()
-{
-	if (page < pages)
-		loadPage(page+1);
-}
-
-
-void Preview::slotGotoFirstPage()
-{
-	if (page > 1)
-		loadPage(1);
-}
-
-
-void Preview::slotGotoLastPage()
-{
-	if (page < pages)
-		loadPage(pages);
+	MailDlg maildlg(this, "maildlg");
+	maildlg.mailFax(m_name);
+	maildlg.exec();
 }
 
 
@@ -848,21 +854,55 @@ void Preview::slotViewRotate()
 }
 
 
-void Preview::slotOptionsShowToolbar()
+void Preview::slotGoPreviousPage()
 {
-	bool toolBarOn = !optionsMenu->isItemChecked(ID_PRE_OPTIONS_TOOLBAR);
-
-	menuBar()->setItemChecked(ID_PRE_OPTIONS_TOOLBAR, toolBarOn);
-	enableToolBar(toolBarOn ? KToolBar::Show : KToolBar::Hide);
+	if (page > 1)
+		loadPage(page-1);
 }
 
 
-void Preview::slotOptionsShowStatusbar()
+void Preview::slotGoNextPage()
 {
-	bool statusBarOn = !optionsMenu->isItemChecked(ID_PRE_OPTIONS_STATUSBAR);
+	if (page < pages)
+		loadPage(page+1);
+}
 
-	menuBar()->setItemChecked(ID_PRE_OPTIONS_STATUSBAR, statusBarOn);
-	enableStatusBar(statusBarOn ? KStatusBar::Show : KStatusBar::Hide);
+
+void Preview::slotGoFirstPage()
+{
+	if (page > 1)
+		loadPage(1);
+}
+
+
+void Preview::slotGoLastPage()
+{
+	if (page < pages)
+		loadPage(pages);
+}
+
+
+void Preview::slotSettingsShowToolbar()
+{
+	bool toolBarOn = !settingsMenu->isItemChecked(ID_PRE_SETTINGS_TOOLBAR);
+
+	menuBar()->setItemChecked(ID_PRE_SETTINGS_TOOLBAR, toolBarOn);
+	if (toolBarOn)
+		toolBar()->show();
+	else
+		toolBar()->hide();
+}
+
+
+void Preview::slotSettingsShowStatusbar()
+{
+	bool statusBarOn = !settingsMenu->isItemChecked(ID_PRE_SETTINGS_STATUSBAR);
+
+	menuBar()->setItemChecked(ID_PRE_SETTINGS_STATUSBAR, statusBarOn);
+	if (statusBarOn)
+		statusBar()->show();
+	else
+		statusBar()->hide();
 }
 
 
@@ -874,35 +914,27 @@ void Preview::slotStatusName(const QString& text)
 
 void Preview::slotStatusSize(int width_, int height_, bool normal)
 {
-	QString s;
-	
 	if (width_)
-		s.sprintf("%d%d, %s", width_, height_, normal ? i18n("Normal") : i18n("Fine"));
+		statusBar()->changeItem(QString("%1%2, %3").arg(width_).arg(height_).arg(normal ? i18n("Normal") : i18n("Fine")), ID_PRE_STATUS_SIZE);
 	else
-		s = "";
-	statusBar()->changeItem(s, ID_PRE_STATUS_SIZE);
+		statusBar()->changeItem("", ID_PRE_STATUS_SIZE);
 }
 
 
 void Preview::slotStatusPage(int page_, int pages_)
 {
-	QString s;
-	
 	if (page_)
-		s.sprintf(i18n("Page %d of %d"), page_, pages_);
+		statusBar()->changeItem(i18n("Page %1 of %2").arg(page_).arg(pages_), ID_PRE_STATUS_PAGE);
 	else
-		s = "";
-	statusBar()->changeItem(s, ID_PRE_STATUS_PAGE);
+		statusBar()->changeItem("", ID_PRE_STATUS_PAGE);
 }
 
 
 void Preview::slotStatusAngle()
 {
 	static const int angles[4] = { 0, 90, 180, 270 };
-	QString s;
 
-	s.sprintf("%d", angles[angle]);
-	statusBar()->changeItem(s, ID_PRE_STATUS_ANGLE);
+	statusBar()->changeItem(QString("%1").arg(angles[angle]), ID_PRE_STATUS_ANGLE);
 }
 
 
@@ -912,14 +944,6 @@ void Preview::slotStatusSender(const QString& text)
 }
 
 
-void Preview::hide()
-{
-	saveOptions();
-
-	KTMainWindow::hide();
-}
-
-
 void Preview::deletePages()
 {
 	int i;
@@ -962,23 +986,23 @@ void Preview::loadPage(int p)
 	slotStatusSize(0, 0, true);
 	slotStatusPage(0, 0);
 	slotStatusAngle();
-	
+
 	deletePages();
 
 	page = p;
 
-	enableCommand(ID_PRE_GOTO_PREVIOUS, page != 1);
-	enableCommand(ID_PRE_GOTO_NEXT, page != pages);
-	enableCommand(ID_PRE_GOTO_FIRST, page != 1);
-	enableCommand(ID_PRE_GOTO_LAST, page != pages);
+	enableCommand(ID_PRE_GO_PREVIOUS, page != 1);
+	enableCommand(ID_PRE_GO_NEXT, page != pages);
+	enableCommand(ID_PRE_GO_FIRST, page != 1);
+	enableCommand(ID_PRE_GO_LAST, page != pages);
 
 	if (!file.open()) {
-		KMsgBox::message(0, i18n("File Error"), i18n("Cannot open facsimile file."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot open facsimile file."), i18n("File Error"));
 		showPage();
 		return;
 	}
 	if (!file.readPageInfo(p, &info)) {
-		KMsgBox::message(0, i18n("File Error"), i18n("Cannot read facsimile page info."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot read facsimile page info."), i18n("File Error"));
 		file.close();
 		showPage();
 		return;
@@ -1022,9 +1046,3 @@ void Preview::loadPage(int p)
 
 	showPage();
 }
-
-
-void Preview::closeEvent(QCloseEvent *)
-{
-	hide();
-}
