@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #include <qscrollbar.h>
 #include <qstring.h>
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <kconfig.h>
 #include <kaccel.h>
 
@@ -46,28 +46,29 @@
 #include <X11/Xlib.h>
 
 
-#define ID_PRE_FILE_PRINT         10010
-#define ID_PRE_FILE_EXPORT        10020
-#define ID_PRE_FILE_MAIL          10030
-#define ID_PRE_FILE_CLOSE         10040
+#define ID_PRE_FILE_PRINT           10010
+#define ID_PRE_FILE_EXPORT          10020
+#define ID_PRE_FILE_MAIL            10030
+#define ID_PRE_FILE_CLOSE           10040
 
-#define ID_PRE_GOTO_PREVIOUS      11010
-#define ID_PRE_GOTO_NEXT          11020
-#define ID_PRE_GOTO_FIRST         11030
-#define ID_PRE_GOTO_LAST          11040
+#define ID_PRE_VIEW_ZOOM_IN         11010
+#define ID_PRE_VIEW_ZOOM_OUT        11020
+#define ID_PRE_VIEW_ROTATE          11030
 
-#define ID_PRE_VIEW_ZOOM_IN       12010
-#define ID_PRE_VIEW_ZOOM_OUT      12020
-#define ID_PRE_VIEW_ROTATE        12030
+#define ID_PRE_GO_PREVIOUS          12010
+#define ID_PRE_GO_NEXT              12020
+#define ID_PRE_GO_FIRST             12030
+#define ID_PRE_GO_LAST              12040
 
-#define ID_PRE_OPTIONS_TOOLBAR    13010
-#define ID_PRE_OPTIONS_STATUSBAR  13020
+#define ID_PRE_SETTINGS_TOOLBAR     13010
+#define ID_PRE_SETTINGS_STATUSBAR   13020
+#define ID_PRE_SETTINGS_SAVEOPTIONS 13030
 
-#define ID_PRE_STATUS_NAME         1001
-#define ID_PRE_STATUS_SIZE         1002
-#define ID_PRE_STATUS_PAGE         1003
-#define ID_PRE_STATUS_ANGLE        1004
-#define ID_PRE_STATUS_SENDER       1005
+#define ID_PRE_STATUS_NAME          1001
+#define ID_PRE_STATUS_SIZE          1002
+#define ID_PRE_STATUS_PAGE          1003
+#define ID_PRE_STATUS_ANGLE         1004
+#define ID_PRE_STATUS_SENDER        1005
 
 
 
@@ -75,14 +76,15 @@ class FaxWidget : public QWidget
 {
 	Q_OBJECT
 public:
-	FaxWidget(QWidget *parent = 0, const char *name = 0, WFlags f = 0);
-	~FaxWidget();
+	FaxWidget(QWidget *parent = 0, const char *name = 0);
+	virtual ~FaxWidget();
 
 	bool lsbFirst();
 
 	void setImage(int w, int h, char *data);
 	void deleteImage();
 
+	void updateGeometry();
 	bool x11EventFilter(XEvent *ev);
 
 	Window window;
@@ -103,9 +105,6 @@ protected:
 	virtual void paintEvent(QPaintEvent *);
 	virtual void resizeEvent(QResizeEvent *);
 
-protected slots:
-	virtual void updateRects();
-
 private:
 	int scrollx, scrolly;
 
@@ -131,14 +130,14 @@ extern FaxWidget *fw;
 
 
 
-class Preview : public KTMainWindow
+class Preview : public KMainWindow
 {
 	Q_OBJECT
 public:
-	Preview(const char *name = 0);
-	~Preview();
+	Preview(QWidget *parent = 0, const char *name = 0);
+	virtual ~Preview();
 
-	void showFax(const QString& name, const QString& alias);
+	void showFax(const QString& name);
 
 	void enableCommand(int id_, bool enable);
 
@@ -150,7 +149,7 @@ protected:
 	void initToolBar();
 	void initStatusBar();
 	void initKeyAccel();
-
+	
 public slots:
 	void commandCallback(int id_);
 
@@ -158,41 +157,34 @@ public slots:
 	void slotFileExport();
 	void slotFileMail();
 
-	void slotGotoFirstPage();
-	void slotGotoPreviousPage();
-	void slotGotoNextPage();
-	void slotGotoLastPage();
-	
 	void slotViewZoomIn();
 	void slotViewZoomOut();
 	void slotViewRotate();
 
-	void slotOptionsShowToolbar();
-	void slotOptionsShowStatusbar();
+	void slotGoFirstPage();
+	void slotGoPreviousPage();
+	void slotGoNextPage();
+	void slotGoLastPage();
+
+	void slotSettingsShowToolbar();
+	void slotSettingsShowStatusbar();
 	
 	void slotStatusName(const QString& text);
 	void slotStatusSize(int page_width, int page_height, bool normal);
-	void slotStatusPage(int page_, int pages_);
+	void slotStatusPage(int page, int pages);
 	void slotStatusAngle();
 	void slotStatusSender(const QString& text);
 	
-	virtual void hide();
-
 private:
 	void deletePages();
 	void showPage();
 	void loadPage(int p);
 
-protected:
-	virtual void closeEvent(QCloseEvent *);
-
-
-private:
 	KConfig *config;
 
 	KAccel *keyAccel;
 
-	QString fname, salias;
+	QString m_name;
 	MLOFile file;
 
 	char *page_datas[3];
@@ -203,12 +195,11 @@ private:
 	int angle;
 
 	QPopupMenu *fileMenu;
-	QPopupMenu *gotoMenu;
 	QPopupMenu *viewMenu;
-	QPopupMenu *optionsMenu;
+	QPopupMenu *goMenu;
+	QPopupMenu *settingsMenu;
 
 	FaxWidget *view;
-
 };
 
 
