@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,51 +33,45 @@
 #include <qradiobutton.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
-#include <qframe.h>
 #include <qtooltip.h>
 #include <qsize.h>
 #include <qdir.h>
 
 #include <kapp.h>
+#include <klocale.h>
 #include <kiconloader.h>
-#include <kmsgbox.h>
+#include <kmessagebox.h>
 #include <kfiledialog.h>
+#include <kseparator.h>
 
 #include "printdlg.h"
 #include "global.h"
 #include "mlofile.h"
-#include "preferences.h"
 #include "filters.h"
 
 
 
-PrintDlg *printdlg = 0;
 
-
-
-
-PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, true)
+PrintDlg::PrintDlg(QWidget *parent, const char *name) : KDialog (parent, name, true)
 {
 	QBoxLayout *vbox, *hbox, *fvbox, *fhbox;
 	QRadioButton *rb;
 	QGroupBox *gb;
-	QPushButton *ok, *cancel;
+	KSeparator *separator;
+	QPushButton *help, *ok, *cancel;
 	QLabel *l1, *l2, *l3;
-	QFrame *frame;
 	QSize size;
 
-	config = kapp->getConfig();
-
-	gotToolTips = false;
+	config = kapp->config();
 
 	to_printer = true;
 	paper_num = 0;
 
-	vbox = new QVBoxLayout(this , 8);
+	vbox = new QVBoxLayout(this , marginHint());
 
 	destination = new QButtonGroup(this);
 	destination->setTitle(i18n("Print Destination"));
-	fvbox = new QVBoxLayout(destination, 12);
+	fvbox = new QVBoxLayout(destination, 12, 0);
 	fvbox->addSpacing(8);
 	rb = new QRadioButton(i18n("Print to &printer:"), destination);
 	rb->setMinimumSize(rb->sizeHint());
@@ -89,7 +83,10 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	printer = new QLineEdit(destination);
 	printer->setMinimumWidth(printer->sizeHint().width());
 	printer->setFixedHeight(printer->sizeHint().height());
-	fhbox->addWidget(printer);
+	fhbox->addWidget(printer, 3);
+
+	fvbox->addSpacing(6);
+
 	rb = new QRadioButton(i18n("Print to &file:"), destination);
 	rb->setMinimumSize(rb->sizeHint());
 	fvbox->addWidget(rb);
@@ -102,10 +99,13 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	file->setText("facsimile.ps");
 	file->setEnabled(false);
 	fhbox->addWidget(file);
+
+	fhbox->addSpacing(6);
 	
 	browse = new QPushButton(destination);
-	browse->setPixmap(Icon("fileopen.xpm"));
-	browse->setFixedSize(browse->sizeHint());	
+	browse->setAutoDefault(false);
+	browse->setPixmap(SmallIcon("fileopen"));
+	browse->setFixedSize(browse->sizeHint()+QSize(4, 4));	
 	browse->setEnabled(false);
 	fhbox->addWidget(browse);
 	
@@ -118,23 +118,23 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	paper_format = new QButtonGroup(i18n("Paper Format"), this);
 	fvbox = new QVBoxLayout(paper_format, 10);
 	fvbox->addSpacing(8);
-	rb = new QRadioButton(i18n("A4 (210297 mm)"), paper_format);
+	rb = new QRadioButton(QString("%1 (210297 mm)").arg(i18n("A4")), paper_format);
 	rb->setMinimumSize(rb->sizeHint());
 	rb->setChecked(true);
 	fvbox->addWidget(rb);
-	rb = new QRadioButton(i18n("B4 (257364 mm)"), paper_format);
+	rb = new QRadioButton(QString("%1 (257364 mm)").arg(i18n("B4")), paper_format);
 	rb->setMinimumSize(rb->sizeHint());
 	fvbox->addWidget(rb);
-	rb = new QRadioButton(i18n("B5 (182257 mm)"), paper_format);
+	rb = new QRadioButton(QString("%1 (182257 mm)").arg(i18n("B5")), paper_format);
 	rb->setMinimumSize(rb->sizeHint());
 	fvbox->addWidget(rb);
-	rb = new QRadioButton(i18n("Letter (811 in.)"), paper_format);
+	rb = new QRadioButton(QString("%1 (811 in.)").arg(i18n("Letter")), paper_format);
 	rb->setMinimumSize(rb->sizeHint());
 	fvbox->addWidget(rb);
-	rb = new QRadioButton(i18n("Legal (814 in.)"), paper_format);
+	rb = new QRadioButton(QString("%1 (814 in.)").arg(i18n("Legal")), paper_format);
 	rb->setMinimumSize(rb->sizeHint());
 	fvbox->addWidget(rb);
-	rb = new QRadioButton(i18n("Executive (710 in.)"), paper_format);
+	rb = new QRadioButton(QString("%1 (710 in.)").arg(i18n("Executive")), paper_format);
 	rb->setMinimumSize(rb->sizeHint());
 	fvbox->addWidget(rb);
 	fvbox->activate();
@@ -146,7 +146,7 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	fvbox->addSpacing(8);
 	fhbox = new QHBoxLayout();
 	fvbox->addLayout(fhbox);
-	l1 = new QLabel(i18n("F&rom page"), gb);
+	l1 = new QLabel(i18n("F&rom page:"), gb);
 	fhbox->addWidget(l1);
 	from_page = new QSpinBox(1, 999, 1, gb);
 	l1->setBuddy(from_page);
@@ -156,7 +156,7 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	fhbox->addWidget(from_page, 1);
 	fhbox = new QHBoxLayout();
 	fvbox->addLayout(fhbox);
-	l2 = new QLabel(i18n("&To page"), gb);
+	l2 = new QLabel(i18n("&To page:"), gb);
 	fhbox->addWidget(l2);
 	to_page = new QSpinBox(1, 999, 1, gb);
 	l2->setBuddy(to_page);
@@ -165,14 +165,12 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	to_page->setFixedHeight(to_page->sizeHint().height());
 	fhbox->addWidget(to_page, 1);
 
-	frame = new QFrame(gb);
-	frame->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	frame->setFixedHeight(6);
-	fvbox->addWidget(frame, 1);
+	separator = new KSeparator(KSeparator::HLine, gb);
+	fvbox->addWidget(separator, 1);
 	
 	fhbox = new QHBoxLayout();
 	fvbox->addLayout(fhbox);
-	l3 = new QLabel(i18n("Number of &copies"), gb);
+	l3 = new QLabel(i18n("Number of &copies:"), gb);
 	fhbox->addWidget(l3);
 	copies = new QSpinBox(1, 99, 1, gb);
 	l3->setBuddy(copies);
@@ -181,10 +179,8 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	copies->setFixedHeight(copies->sizeHint().height());
 	fhbox->addWidget(copies, 1);
 
-	frame = new QFrame(gb);
-	frame->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	frame->setFixedHeight(6);
-	fvbox->addWidget(frame, 1);
+	separator = new KSeparator(KSeparator::HLine, gb);
+	fvbox->addWidget(separator, 1);
 	
 	level2 = new QCheckBox(i18n("&Language Level 2"), gb);
 	level2->setMinimumSize(level2->sizeHint());
@@ -203,19 +199,24 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 
 	hbox->addWidget(gb);
 
-	hbox = new QHBoxLayout(8);
+	separator = new KSeparator(KSeparator::HLine, this);
+	vbox->addWidget(separator);
+	
+	hbox = new QHBoxLayout();
 	vbox->addLayout(hbox);
 
-	hbox->addStretch(1);
-
-	ok = new QPushButton(i18n("OK"), this);
+	help = new QPushButton(i18n("&Help"), this);
+	ok = new QPushButton(i18n("&OK"), this);
 	ok->setDefault(true);
-	cancel = new QPushButton(i18n("Cancel"), this);
-	size = ok->sizeHint().expandedTo(cancel->sizeHint());
+	cancel = new QPushButton(i18n("&Cancel"), this);
+	size = help->sizeHint().expandedTo(ok->sizeHint().expandedTo(cancel->sizeHint()));
 
+	help->setFixedSize(size);
 	ok->setFixedSize(size);
 	cancel->setFixedSize(size);
 
+	hbox->addWidget(help);
+	hbox->addStretch();
 	hbox->addWidget(ok);
 	hbox->addWidget(cancel);
 
@@ -228,32 +229,8 @@ PrintDlg::PrintDlg(QWidget *parent, const char *name) : QDialog (parent, name, t
 	interpolate->setChecked(config->readBoolEntry(ID_PREF_PRT_INTERPOL, PREF_PRT_INTERPOL));
 	interpolate->setEnabled(level2->isChecked());
 	
-	connect(destination, SIGNAL(clicked(int)), SLOT(destinationSelected(int)));
-	connect(browse, SIGNAL(clicked()), SLOT(browseClicked()));
-	connect(paper_format, SIGNAL(clicked(int)), SLOT(formatSelected(int)));
-	connect(level2, SIGNAL(toggled(bool)), SLOT(level2Selected(bool)));
-	connect(ok, SIGNAL(clicked()), SLOT(okClicked()));
-	connect(cancel, SIGNAL(clicked()), SLOT(reject()));
-
-	setCaption(i18n("KMLOFax Print"));
-
-	resize(sizeHint());
-}
-
-
-PrintDlg::~PrintDlg()
-{
-}
-
-
-void PrintDlg::addToolTips(bool on)
-{
-	if (on == gotToolTips)
-		return;
-
-	gotToolTips = on;
-
-	if (gotToolTips) {
+	config->setGroup(ID_PREF_GROUP_GENERAL);
+	if (config->readBoolEntry(ID_PREF_GEN_TOOLTIPS, PREF_GEN_TOOLTIPS)) {
 		QToolTip::add(printer, i18n("Command to invoke for printing"));
 		QToolTip::add(file, i18n("Name of file to print to"));
 		QToolTip::add(browse, i18n("Select file to print to"));
@@ -264,31 +241,34 @@ void PrintDlg::addToolTips(bool on)
 		QToolTip::add(level2, i18n("Use PostScript Language Level 2"));
 		QToolTip::add(interpolate, i18n("Interpolate for smoother output"));
 	}
-	else {
-		QToolTip::remove(printer);
-		QToolTip::remove(file);
-		QToolTip::remove(browse);
-		QToolTip::remove(paper_format);
-		QToolTip::remove(from_page);
-		QToolTip::remove(to_page);
-		QToolTip::remove(copies);
-		QToolTip::remove(level2);
-		QToolTip::remove(interpolate);
-	}
-}	
+	
+	connect(destination, SIGNAL(clicked(int)), SLOT(destinationSelected(int)));
+	connect(browse, SIGNAL(clicked()), SLOT(slotBrowse()));
+	connect(paper_format, SIGNAL(clicked(int)), SLOT(formatSelected(int)));
+	connect(level2, SIGNAL(toggled(bool)), SLOT(level2Selected(bool)));
+	connect(help, SIGNAL(clicked()), SLOT(slotHelp()));
+	connect(ok, SIGNAL(clicked()), SLOT(slotOk()));
+	connect(cancel, SIGNAL(clicked()), SLOT(reject()));
+
+	setCaption(i18n("Print"));
+
+	resize(sizeHint());
+}
 
 
-void PrintDlg::printFax(const QString& name, const QString& alias)
+PrintDlg::~PrintDlg()
+{
+}
+
+
+void PrintDlg::printFax(const QString& name)
 {
 	MLOFile mlofile;
 
-	fname = name;
-	salias = alias;
-
 	mlofile.setName(name);
 
 	if (!mlofile.open()) {
-		KMsgBox::message(0, i18n("File Error"), i18n("Cannot open facsimile file."), KMsgBox::EXCLAMATION);
+		KMessageBox::sorry(this, i18n("Cannot open facsimile file."), i18n("File Error"));
 		return;
 	}
 
@@ -298,29 +278,35 @@ void PrintDlg::printFax(const QString& name, const QString& alias)
 	to_page->setValue(mlofile.pages());
 	mlofile.close();
 
-	if (isVisible())
-		raise();
-	else
-		show();
+	m_name = name;
 }
 
 
-void PrintDlg::browseClicked()
+void PrintDlg::slotBrowse()
 {
-	QString s;
+	QString s = file->text();
 	
-	s = KFileDialog::getSaveFileName(QDir::currentDirPath(), i18n("*.ps|PostScript Files (*.ps)\n*|All Files (*)"), this);
+	if (s.isEmpty())
+		s = QDir::currentDirPath();
+
+	s = KFileDialog::getSaveFileName(s, i18n("*.ps|PostScript Files (*.ps)\n*|All Files (*)"), this);
 	if (!s.isEmpty())
 		file->setText(s);
 }
 
 
-void PrintDlg::okClicked()
+void PrintDlg::slotHelp()
+{
+	kapp->invokeHelp("PRINT-HELP");
+}
+
+
+void PrintDlg::slotOk()
 {
 	MLO2PSFilter *filter;
 	FILE *ps;
 
-	filter = new MLO2PSFilter(fname);
+	filter = new MLO2PSFilter(m_name);
 	filter->setFormat(paper_num);
 	filter->setLevel2(level2->isChecked());
 	filter->setInterpolate(interpolate->isChecked());
@@ -335,29 +321,34 @@ void PrintDlg::okClicked()
 		config->readNumEntry(ID_PREF_PRT_BMARGIN, PREF_PRT_BMARGIN)
 	);
 
-	kapp->setOverrideCursor(waitCursor);
 
 	if (to_printer) {
-		if ((ps = popen(printer->text(), "w")) <= 0) {
-			KMsgBox::message(0, i18n("Printer Error"), i18n("Cannot execute print command."), KMsgBox::EXCLAMATION);
-		} else {
-			filter->convertFile(ps, salias);
+		got_sigpipe = false;
+		if ((ps = popen(printer->text(), "w")) <= 0)
+			KMessageBox::sorry(this, i18n("Error executing print command."), i18n("Printer Error"));
+		else {
+			kapp->setOverrideCursor(waitCursor);
+			filter->convertFile(ps);
 			pclose(ps);
+			kapp->restoreOverrideCursor();
+			if (got_sigpipe)
+				KMessageBox::sorry(this, i18n("Error executing print command."), i18n("Printer Error"));
 		}
-	} else {
-		if ((ps = fopen(file->text(), "w")) == 0) {
-			KMsgBox::message(0, i18n("Printer Error"), i18n("Cannot create file for output."), KMsgBox::EXCLAMATION);
-		} else {
-			filter->convertFile(ps, salias);
+	}
+	else {
+		if ((ps = fopen(file->text(), "w")) == 0)
+			KMessageBox::sorry(this, i18n("Cannot create file for output."), i18n("Printer Error"));
+		else {
+			kapp->setOverrideCursor(waitCursor);
+			filter->convertFile(ps);
 			fclose(ps);
+			kapp->restoreOverrideCursor();
 		}
 	}		
 
-	kapp->restoreOverrideCursor();
-
 	delete filter;
 
-	hide();
+	accept();
 }
 
 
