@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,19 +32,20 @@
 #include "config.h"
 #endif 
 
-#include <qdialog.h>
 #include <qwidget.h>
 #include <qbuttongroup.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
+#include <qstring.h>
 
+#include <kdialog.h>
 #include <kconfig.h>
 
 
 
-class PrintDlg : public QDialog
+class PrintDlg : public KDialog
 {
 	Q_OBJECT
 public:
@@ -53,12 +54,13 @@ public:
 
 	void addToolTips(bool on);
 
-	void printFax(const QString& name, const QString& alias);
+	void printFax(const QString& name);
 
-private slots:
-	void browseClicked();
+protected slots:
+	void slotBrowse();
 	
-	void okClicked();
+	void slotHelp();
+	void slotOk();
 
 	void destinationSelected(int id_);
 	void formatSelected(int id_);
@@ -85,7 +87,7 @@ private:
 
 	QButtonGroup *paper_format;
 
-	QString fname, salias;
+	QString m_name;
 };
 
 
