@@ -1,10 +1,10 @@
 /*
     KMLOFax
     
-    A utility to process facsimile received with the ELSA
+    A utility to process facsimiles received with the ELSA
     MicroLink(tm) Office modem.
 
-    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>
+    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,15 +31,56 @@
 #include "config.h"
 #endif 
 
-#include <qdialog.h>
 #include <qwidget.h>
+#include <qstring.h>
+#include <qcstring.h>
 #include <qlistview.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 
+#include <kdialog.h>
 
 
-class SenderAliases : public QDialog
+#define SENDER_ALIAS(x) (senderaliases->alias(x))
+
+
+class EditAlias : public KDialog
+{
+	Q_OBJECT
+public:
+	EditAlias(QWidget *parent = 0, const char *name = 0);
+	~EditAlias();
+
+	void setSender(QString sender_);
+	QString sender();
+	void setAlias(QString alias_);
+	QString alias();
+
+private:
+	QLineEdit *m_sender;
+	QLineEdit *m_alias;
+};
+
+
+inline void EditAlias::setSender(QString sender_)
+{	m_sender->setText(sender_); };
+
+
+inline QString EditAlias::sender()
+{	return m_sender->text(); };
+
+
+inline void EditAlias::setAlias(QString alias_)
+{	m_alias->setText(alias_); };
+
+
+inline QString EditAlias::alias()
+{	return m_alias->text(); };
+
+
+
+
+class SenderAliases : public KDialog
 {
 	Q_OBJECT
 public:
@@ -52,14 +93,16 @@ public:
 	void addToolTips(bool on);
 
 public slots:
-	QString alias(const char *id_);
-	void setAlias(const char *id_);
+	QString alias(const QCString& id_);
+	void setAlias(const QCString& id_);
 
-private slots:
+protected slots:
+	void selectionChangedSlot(QListViewItem *item);
+	void executedSlot(QListViewItem *);
 	void addItem();
+	void editItem();
 	void deleteItem();
-	void applyItem();
-	void currentChangedSlot(QListViewItem *item);
+	void slotHelp();
 
 signals:
 	void applyButtonPressed();
@@ -67,16 +110,12 @@ signals:
 private:
 	bool gotToolTips;
 
-	bool entry_changed;
-
-	QLineEdit *sender_id;
-	QLineEdit *sender_name;
-	QPushButton *bapply;
+	QPushButton *add_item, *edit_item, *del_item;
 	QListView *list;
-	QPushButton *badd, *bdel, *bclose;
 };
 
 
 extern SenderAliases *senderaliases;
 
+
 #endif // SENDERALIASES_H
